@@ -82,7 +82,7 @@ readArraySDML <- function(x)
         vals <- as.POSIXct(strptime(vals, format="%Y-%m-%dT%H:%M:%S"))
 
       if (type$type == "character")
-        vals <- as.character(vals)
+        vals[] <- as.character(vals)
     }
     
     atvals <- attributes(vals)
@@ -155,9 +155,9 @@ getTextDataSDML <- function(y, attribs, type)
   if (type == "character")
     y[y == attribs[["null.string"]]] <- ""
   if (type == "numeric") {
-    y <- gsub(attribs[["neginf.string"]], "-Inf", y)
-    y <- gsub(attribs[["posinf.string"]], "Inf", y)
-    y <- gsub(attribs[["nan.string"]], "NaN", y)
+    y[grep(attribs[["neginf.string"]], y, fixed = TRUE)] <- "-Inf"
+    y[grep(attribs[["posinf.string"]], y, fixed = TRUE)] <- "Inf"
+    y[grep(attribs[["nan.string"]], y, fixed = TRUE)] <- "NaN"
   }
   if (type == "logical") {
     y[y == attribs[["true"]]] <- "1"
